from mkdocs.plugins import BasePlugin
from bs4 import BeautifulSoup

class MarkdownMermaidPlugin(BasePlugin):
   
    def on_post_page(self, output_content, config, **kwargs):
        soup = BeautifulSoup(output_content, 'html.parser')
        for mermaid in soup.find_all("code",class_="mermaid"):
            # replace code with div
            mermaid.name="div"
            # replace <pre> 
            mermaid.parent.replace_with(mermaid)
            # print mermaid.parent
        return unicode(soup)


import os
from setuptools import setup, find_packages


def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()


setup(
    name='mkdocs-mermaid-plugin',
    version='0.0.2',
    description='A MkDocs plugin that support mermaid graph',
    long_description=read('README.md'),
    keywords='mkdocs python markdown mermaid',
    url='https://github.com/pugong/mkdocs-mermaid-plugin',
    author='pugong',
    author_email='pugong.liu@gmail.com',
    license='MIT',
    python_requires='>=2.7',
    install_requires=[
        'mkdocs>=0.17'
    ],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Intended Audience :: Information Technology',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7'
    ],
    packages=find_packages(exclude=['*.tests']),
    entry_points={
        'mkdocs.plugins': [
            'markdownmermaid = markdownmermaid.plugin:MarkdownMermaidPlugin'
        ]
    }
)
